@@ -16,7 +16,7 @@ from annofabapi.exceptions import AnnofabApiException
 from annofabapi.models import (AnnotationDataHoldingType, AnnotationSpecsV1, InputData, Inspection, InspectionStatus,
                                Instruction, JobInfo, JobStatus, JobType, MyOrganization, Organization,
                                OrganizationMember, Project, ProjectMember, SupplementaryData, Task)
-from annofabapi.utils import allow_404_error, first_true
+from annofabapi.utils import allow_404_error
 
 logger = logging.getLogger(__name__)
 
@@ -41,6 +41,10 @@ class AnnotationSpecsRelation:
     choice_id: Dict[ChoiceKey, ChoiceKey]
 
 
+def __first_true(iterable, default=None, pred=None):
+    return next(filter(pred, iterable), default)
+
+
 class Wrapper:
     """
     AnnofabApiのラッパー.
@@ -389,7 +393,7 @@ class Wrapper:
         dict_label_id: Dict[str, str] = {}
         for src_label in src_annotation_specs["labels"]:
             src_label_name_en = self.__get_label_name_en(src_label)
-            dest_label = first_true(dest_labels, pred=lambda e, f=src_label_name_en: self.__get_label_name_en(e) == f)
+            dest_label = __first_true(dest_labels, pred=lambda e, f=src_label_name_en: self.__get_label_name_en(e) == f)
             if dest_label is not None:
                 dict_label_id[src_label["label_id"]] = dest_label["label_id"]
 
@@ -397,7 +401,7 @@ class Wrapper:
         dict_choice_id: Dict[ChoiceKey, ChoiceKey] = {}
         for src_additional in src_annotation_specs["additionals"]:
             src_additional_name_en = self.__get_additional_data_definition_name_en(src_additional)
-            dest_additional = first_true(
+            dest_additional = __first_true(
                 dest_additionals,
                 pred=lambda e, f=src_additional_name_en: self.__get_additional_data_definition_name_en(e) == f)
             if dest_additional is None:
@@ -409,8 +413,8 @@ class Wrapper:
             dest_choices = dest_additional["choices"]
             for src_choice in src_additional["choices"]:
                 src_choice_name_en = self.__get_choice_name_en(src_choice)
-                dest_choice = first_true(dest_choices,
-                                         pred=lambda e, f=src_choice_name_en: self.__get_choice_name_en(e) == f)
+                dest_choice = __first_true(dest_choices,
+                                           pred=lambda e, f=src_choice_name_en: self.__get_choice_name_en(e) == f)
                 if dest_choice is not None:
                     dict_choice_id[ChoiceKey(src_additional["additional_data_definition_id"],
                                              src_choice["choice_id"])] = ChoiceKey(
@@ -980,13 +984,15 @@ class Wrapper:
     #########################################
     # Public Method : Task
     #########################################
-    def initiate_tasks_generation_by_csv(self, project_id: str, csvfile_path: str) -> Dict[str, Any]:
+    def initiate_tasks_generation_by_csv(self, project_id: str, csvfile_path: str,
+                                         query_params: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
         """
         タスクID,入力データ名,入力データID」を1行毎に指定したCSVを使って、タスクを生成する
 
         Args:
             project_id: プロジェクトID
             csvfile_path: CSVファイルのパス
+            query_params: `initiate_tasks_generation` メソッドに渡す`query_params`
 
         Returns:
             `initiate_tasks_generation` APIのContent
@@ -1002,7 +1008,7 @@ class Wrapper:
             },
             'project_last_updated_datetime': project_last_updated_datetime
         }
-        return self.api.initiate_tasks_generation(project_id, request_body=request_body)[0]
+        return self.api.initiate_tasks_generation(project_id, request_body=request_body, query_params=query_params)[0]
 
     @allow_404_error
     def get_task_or_none(self, project_id: str, task_id: str) -> Optional[Task]:
